==> haskell-tz-0.1.3.6-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-4wyOhKOFwTx2dQ2rjQnwf0
key:                  tz-0.1.3.6-4wyOhKOFwTx2dQ2rjQnwf0
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  f7562f8853253ab3d5158733f7322492
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Internal.CoerceTH Data.Time.Zones.Read
    Data.Time.Zones.TH Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-4wyOhKOFwTx2dQ2rjQnwf0
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 template-haskell-2.17.0.0 time-1.9.3
    tzdata-0.2.20220815.0-2FrvdV9vR8o6GbZ4QLAtMp
    vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tz-0.1.3.6-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tz.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tz
version:              0.1.3.6
visibility:           public
id:                   tz-0.1.3.6-8aK2r7HcEA1Jm3bMSxoU20
key:                  tz-0.1.3.6-8aK2r7HcEA1Jm3bMSxoU20
license:              Apache-2.0
maintainer:           Janus Troelsen <ysangkok@gmail.com>
author:               Mihaly Barasz, Gergely Risko
stability:            experimental
homepage:             https://github.com/ysangkok/haskell-tz
synopsis:             Efficient time zone handling
description:
    The goal of this package is to provide a library that can read time
    zone info files (aka. Olson files), and does time zone conversions
    in a /pure/ and /efficient/ way.

    We also provide platform-independent and/or compiled-in access to
    the standard Time Zone Dabase by the means of the companion @tzdata@
    package <http://hackage.haskell.org/package/tzdata>.

    The package is currently in an alpha phase, I'\''m still experimenting
    with different ideas wrt. scope\/API\/implementation\/etc. All
    comments are welcome!

category:             Data
abi:                  b87f7551e2d8297c05cb5f39014ce53d
exposed:              True
exposed-modules:
    Data.Time.Zones Data.Time.Zones.All Data.Time.Zones.Internal
    Data.Time.Zones.Internal.CoerceTH Data.Time.Zones.Read
    Data.Time.Zones.TH Data.Time.Zones.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tz-0.1.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tz
hs-libraries:         HStz-0.1.3.6-8aK2r7HcEA1Jm3bMSxoU20
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 data-default-0.7.1.1-BkZarJ3J3008hHF2JOuYeW
    deepseq-1.4.5.0 template-haskell-2.17.0.0 time-1.9.3
    tzdata-0.2.20221011.0-2SNxQ9wdffuGXCsrK8amgw
    vector-0.13.0.0-GsrNLADOwIh8THk5NHujPC

haddock-interfaces:   /usr/share/doc/haskell-tz/html/tz.haddock
haddock-html:         /usr/share/doc/haskell-tz/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
